Index: Source/core/fetch/ResourceFetcher.cpp |
diff --git a/Source/core/fetch/ResourceFetcher.cpp b/Source/core/fetch/ResourceFetcher.cpp |
index 651050f628e91525ac2c0356d49869f13ea22737..b20a6cc3d5c04ba8086851bf68ec3bc5027c0cc6 100644 |
--- a/Source/core/fetch/ResourceFetcher.cpp |
+++ b/Source/core/fetch/ResourceFetcher.cpp |
@@ -860,8 +860,9 @@ ResourceFetcher::RevalidationPolicy ResourceFetcher::determineRevalidationPolicy |
return Reload; |
} |
- // During the initial load, avoid loading the same resource multiple times for a single document, even if the cache policies would tell us to. |
- if (document() && !document()->loadEventFinished() && m_validatedURLs.contains(existingResource->url())) |
+ // During the initial load, avoid loading the same resource multiple times for a single document, |
+ // even if the cache policies would tell us to. Raw resources are exempted. |
+ if (type != Resource::Raw && document() && !document()->loadEventFinished() && m_validatedURLs.contains(existingResource->url())) |
return Use; |
// CachePolicyReload always reloads |